==> pyabr-0.0.8-py3-none-any.whl: README.md <==

# Pyabr clouding system

In the name of God, the Compassionate, the Merciful

Pyabr &copy; 2020 Mani Jamali. Free Software GNU General Public License v3.0

- Install Pyabr with git source
- Install Pyabr with PyPI
- Installaction of Pyabr
- Run Pyabr shell

## Install Pyabr with git source

- Git source from Github
```shell script
git clone https://github.com/manijamali2003/pyabr
```

- Jump to source code then run setup installer 
```shell script
cd pyabr && python setup.py
```

## Install Pyabr with PyPI

- Get package from PyPI
```shell script
pip install pyabr
```

- Run setup installer
```shell script
python -m pyabr
```

## Installaction of Pyabr

[![](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-1.png)](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-1.png)

- After runing setup.py click Next button

[![](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-2.png)](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-2.png)

- Choose non root location for install Pyabr

[![](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-3.png)](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-3.png)

- Fill out the system form

[![](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-4.png)](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-4.png)

- Fill out the account user form then click Finish button

[![](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-5.png)](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-5.png)

- After installing Pyabr, find the installed folder then run **vmnam.pyc** file:

Run Pyabr kernel by this command: 
```shell script
python vmnam.pyc
```

[![](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-6.png)](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-6.png)

Welcome to Pyabr; this is a simple boot splash in this clouding system.

[![](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-7.png)](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-7.png)

- Now you can switch your user

[![](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-8.png)](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-8.png)

- After switching the user account, enter your password then click Enter button in keyboard

[![](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-9.png)](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-9.png)

This is the default Desktop Enviroment for Pyabr

## Run Pyabr shell

- Before run Pyabr run 
```shell script
python vmnam.pyc login
```

or permanetly use no GUI:

```shell script
echo CLI > etc/interface
python vmnam.pyc
```

This README.md file created by editor.md with MIT License

==> pyabr-0.0.9-py3-none-any.whl: README.md <==

# Pyabr clouding system

In the name of God, the Compassionate, the Merciful

Pyabr &copy; 2020 Mani Jamali. Free Software GNU General Public License v3.0

- Install Pyabr with git source
- Install Pyabr with PyPI
- Installaction of Pyabr
- Run Pyabr shell
- Debug Pyabr for developers

## Install Pyabr with git source

- Git source from Github
```shell script
git clone https://github.com/manijamali2003/pyabr
```

- Jump to source code then run setup installer 
```shell script
cd pyabr
pip install -r requirments.txt
python setup.py
```

## Install Pyabr with PyPI

- Get package from PyPI
```shell script
pip install pyabr
```

- Run setup installer
```shell script
python -m pyabr
```

## Installaction of Pyabr

[![](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-1.png)](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-1.png)

- After runing setup.py click Next button

[![](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-2.png)](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-2.png)

- Choose non root location for install Pyabr

[![](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-3.png)](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-3.png)

- Fill out the system form

[![](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-4.png)](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-4.png)

- Fill out the account user form then click Finish button

[![](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-5.png)](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-5.png)

- After installing Pyabr, find the installed folder then run **vmnam.py** file:

Run Pyabr kernel by this command: 
```shell script
python vmnam.py
```

[![](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-6.png)](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-6.png)

Welcome to Pyabr; this is a simple boot splash in this clouding system.

[![](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-7.png)](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-7.png)

- Now you can switch your user

[![](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-8.png)](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-8.png)

- After switching the user account, enter your password then click Enter button in keyboard

[![](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-9.png)](https://raw.githubusercontent.com/manijamali2003/pyabr/master/screenshots/pyabr-screenshot-9.png)

This is the default Desktop Enviroment for Pyabr

## Run Pyabr shell

- Before run Pyabr run 
```shell script
python vmnam.py login
```

or permanetly use no GUI:

```shell script
echo CLI > etc/interface
python vmnam.py
```

## Debug Pyabr for developers

- Debug Pyabr with zone packages (root password is toor):

```shell script
python debug.py
```

- Debug Pyabr with all packages:

```shell script
python fulldebug.py
```

- Debug Pyabr with command line interface

```shell script
python run.py
```

This README.md file created by editor.md with MIT License
